@@ -1,9 +1,13 @@
-use crate::{error::Error, money::Currency, Context, ContextProvider};
-pub use checkout_server_derive::Server;
 use dropshot::{ApiDescription, HttpServerStarter, ServerContext};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
+pub use checkout_server_derive::Server;
+
+use crate::context::{Context, ContextProvider};
+use crate::error::Error;
+use crate::money::Currency;
+
 #[derive(Serialize, Deserialize, JsonSchema)]
 pub struct CreateRequest {
     pub currency: Currency,
